@@ -966,16 +966,19 @@ std::string Context::getTaskContext (const std::string& kind, std::string name,
   }
 
   // Figure out the context string for this kind (read/write)
-  std::string contextString = config.get ("context." + name + "." + kind);
-  if (contextString.empty ())
+  std::string contextString = "";
+
+  if (! config.has ("context." + name + "." + kind) && kind == "read")
   {
     debug ("Specific " + kind + " context for '" + name + "' not defined. ");
     if (fallback)
     {
-      debug ("Falling back on generic.");
+      debug ("Trying to interpret old-style context definition as read context.");
       contextString = config.get ("context." + name);
     }
   }
+  else
+    contextString = config.get ("context." + name + "." + kind);
 
   debug (format ("Detected context string: {1}", contextString.empty() ? "(empty)" : contextString));
   return contextString;
