@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2021, Tomas Babej, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -170,7 +170,7 @@ void TF2::add_task (Task& task)
 
   // For faster lookup
   if (Context::getContext ().cli2.getCommand () == "import")
-    _tasks_map.insert (std::pair<std::string, Task> (task.get("uuid"), task));
+    _tasks_map.emplace (task.get("uuid"), task);
 
   Task::status status = task.getStatus ();
   if (task.id == 0 &&
@@ -355,22 +355,13 @@ void TF2::load_gc (Task& task)
   {
     Context::getContext ().tdb2.pending._tasks.push_back (task);
   }
+  // 2.6.0: Waiting status is deprecated. Convert to pending to upgrade status
+  // field value in the data files.
   else if (status == "waiting")
   {
-    Datetime wait (task.get_date ("wait"));
-    if (wait < now)
-    {
-      task.set ("status", "pending");
-      task.remove ("wait");
-      // Unwaiting pending tasks is the only case not caught by the size()
-      // checks in TDB2::gc(), so we need to signal it here.
-      Context::getContext ().tdb2.pending._dirty = true;
-
-      if (Context::getContext ().verbose ("unwait"))
-        Context::getContext ().footnote (format ("Un-waiting task {1} '{2}'", task.id, task.get ("description")));
-    }
-
+    task.set ("status", "pending");
     Context::getContext ().tdb2.pending._tasks.push_back (task);
+    Context::getContext ().tdb2.pending._dirty = true;
   }
   else
   {
@@ -410,7 +401,7 @@ void TF2::load_tasks (bool from_gc /* = false */)
         _tasks.push_back (task);
 
       if (Context::getContext ().cli2.getCommand () == "import")  // For faster lookup only
-        _tasks_map.insert (std::pair<std::string, Task> (task.get("uuid"), task));
+        _tasks_map.emplace (task.get("uuid"), task);
     }
 
     // TDB2::gc() calls this after loading both pending and completed
@@ -525,29 +516,26 @@ void TF2::dependency_scan ()
   // Iterate and modify TDB2 in-place.  Don't do this at home.
   for (auto& left : _tasks)
   {
-    if (left.has ("depends"))
+    for (auto& dep : left.getDependencyUUIDs ())
     {
-      for (auto& dep : left.getDependencyUUIDs ())
+      for (auto& right : _tasks)
       {
-        for (auto& right : _tasks)
+        if (right.get ("uuid") == dep)
         {
-          if (right.get ("uuid") == dep)
+          // GC hasn't run yet, check both tasks for their current status
+          Task::status lstatus = left.getStatus ();
+          Task::status rstatus = right.getStatus ();
+          if (lstatus != Task::completed &&
+              lstatus != Task::deleted &&
+              rstatus != Task::completed &&
+              rstatus != Task::deleted)
           {
-            // GC hasn't run yet, check both tasks for their current status
-            Task::status lstatus = left.getStatus ();
-            Task::status rstatus = right.getStatus ();
-            if (lstatus != Task::completed &&
-                lstatus != Task::deleted &&
-                rstatus != Task::completed &&
-                rstatus != Task::deleted)
-            {
-              left.is_blocked = true;
-              right.is_blocking = true;
-            }
-
-            // Only want to break out of the "right" loop.
-            break;
+            left.is_blocked = true;
+            right.is_blocking = true;
           }
+
+          // Only want to break out of the "right" loop.
+          break;
         }
       }
     }
@@ -839,6 +827,11 @@ void TDB2::revert ()
     //   - erase from completed
     //   - if in backlog, erase, else cannot undo
 
+    Task old;
+    if (prior != "")
+      old = Task (prior);
+    Context::getContext ().hooks.onModify (Task (current), old);
+
     // Modify other data files accordingly.
     std::vector <std::string> p = pending.get_lines ();
     revert_pending (p, uuid, prior);
@@ -987,7 +980,7 @@ void TDB2::revert_backlog (
   const std::string& current,
   const std::string& prior)
 {
-  std::string uuid_att = "\"uuid\":\"" + uuid + '"';
+  std::string uuid_att = R"("uuid":")" + uuid + '"';
 
   bool found = false;
   for (auto task = b.rbegin (); task != b.rend (); ++task)
@@ -1244,7 +1237,6 @@ void TDB2::show_diff (
 // Possible scenarios:
 // - task in pending that needs to be in completed
 // - task in completed that needs to be in pending
-// - waiting task in pending that needs to be un-waited
 void TDB2::gc ()
 {
   Timer timer;
