@@ -575,14 +575,15 @@ int CmdNews::execute (std::string& output)
   std::stringstream outro;
   outro << underline.colorize (bold.colorize ("Taskwarrior crowdfunding\n"));
   outro << format (
-    "Taskwarrior has been in development for {1} years and its continued survival\n"
+    "Taskwarrior has been in development for {1} years but its survival\n"
     "depends on your support!\n\n"
-    "Please consider joining our {2} fundraiser and visit crowdfunding page at:\n\n",
+    "Please consider joining our {2} fundraiser to help us fund maintenance\n"
+    "and development of new features:\n\n",
     std::lround (static_cast<float>(development_time.days ()) / 365.25),
     now.year ()
   );
   outro << bold.colorize("    https://github.com/sponsors/GothenburgBitFactory/\n\n");
-  outro << "Interesting perks are available for our sponsors.\nSponsorship directly translates to more development time spent on the project.\n";
+  outro << "Perks are available for our sponsors.\n";
 
   std::cout << outro.str ();
 
