@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2021, Tomas Babej, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -35,6 +35,7 @@
 #include <format.h>
 #include <shared.h>
 #include <util.h>
+#include <Task.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 CmdUDAs::CmdUDAs ()
@@ -134,7 +135,9 @@ int CmdUDAs::execute (std::string& output)
   for (auto& i : filtered)
   {
     for (auto& att : i.data)
-      if (att.first.substr (0, 11) != "annotation_" &&
+      if (! Task::isAnnotationAttr (att.first) &&
+          ! Task::isTagAttr (att.first) &&
+          ! Task::isDepAttr (att.first) &&
           Context::getContext ().columns.find (att.first) == Context::getContext ().columns.end ())
         orphans[att.first]++;
   }
